@@ -1,15 +1,21 @@
 import pandas as pd
 
 from chester.features_engineering.fe_nlp import get_embeddings
-from chester.run.user_classes import TextFeatureSpec
+from chester.features_engineering.time_series.ts_feature_extraction import TimeSeriesFeatureExtraction
+from chester.run.user_classes import TextFeatureSpec, TimeSeriesHandler
+from chester.zero_break.problem_specification import DataInfo
 
 
 class FeatureHandler:
     def __init__(self, column, col_name,
                  feature_type=None,
-                 text_feature_extraction: TextFeatureSpec = None):
+                 time_series_handler: TimeSeriesHandler = None,
+                 text_feature_extraction: TextFeatureSpec = None,
+                 data_info: DataInfo = None):
         self.column = column
         self.feature_type = feature_type
+        self.data_info = data_info
+        self.time_series_handler = time_series_handler
         self.col_name = col_name
         self.text_feature_extraction = text_feature_extraction
 
@@ -74,7 +80,20 @@ class FeatureHandler:
         embedding.rename(columns=new_col_name_dict, inplace=True)
         return embedding, embedding.columns
 
-    def handle_feature(self):
+    def handle_time_series(self):
+        ts_fe = TimeSeriesFeatureExtraction(
+            time_series_handler=self.time_series_handler,
+            data_info=self.data_info,
+            col_name=self.col_name,
+            column=self.column
+        )
+        ts_fe.run()
+        print("current columns wow", self.data_info.data.columns)
+        self.data_info = ts_fe.data_info
+
+    def run(self):
+        if self.feature_type == 'time':
+            return self.handle_time_series()
         if self.feature_type == 'numeric':
             return self.handle_numerical()
         elif self.feature_type == 'categorical':
@@ -83,8 +102,6 @@ class FeatureHandler:
             return self.handle_boolean()
         elif self.feature_type == 'text':
             return self.handle_text()
-        elif self.feature_type == 'time':
-            return None, None
         else:
             if not (self.col_name == self.col_name):
                 print(
