@@ -24,7 +24,6 @@ class ImagesData:
         self.label_hanlder()
 
         self.is_colored = True if len(self.image_shape) > 2 else False
-        self.images = self.images.reshape((-1,) + self.image_shape)
         if self.is_colored:
             self.images_to_show = np.transpose(self.images, (0, 2, 3, 1))
         else:
@@ -41,12 +40,21 @@ class ImagesData:
 
     def split(self):
         assert 0 <= self.validation_prop < 0.8, "validation proportion should be in range (0, 0.8)"
-        num_val = int(self.validation_prop * len(self.images))
-        indices = np.random.permutation(len(self.images))
-        val_indices, train_indices = indices[:num_val], indices[num_val:]
-        images_train, labels_train = self.images[train_indices], self.labels[train_indices]
-        images_val, labels_val = self.images[val_indices], self.labels[val_indices]
-        return images_train, labels_train, images_val, labels_val
+        try:
+            self.images = self.images.reshape((-1,) + self.image_shape)
+            num_val = int(self.validation_prop * len(self.images))
+            indices = np.random.permutation(len(self.images))
+            val_indices, train_indices = indices[:num_val], indices[num_val:]
+            images_train, labels_train = self.images[train_indices], self.labels[train_indices]
+            images_val, labels_val = self.images[val_indices], self.labels[val_indices]
+            return images_train, labels_train, images_val, labels_val
+        except:
+            num_val = int(self.validation_prop * len(self.images))
+            indices = np.random.permutation(len(self.images))
+            val_indices, train_indices = indices[:num_val], indices[num_val:]
+            images_train, labels_train = self.images[train_indices], self.labels[train_indices]
+            images_val, labels_val = self.images[val_indices], self.labels[val_indices]
+            return images_train, labels_train, images_val, labels_val
 
     def create_data_loaders(self, batch_size):
         train_dataset = TensorDataset(torch.from_numpy(self.images_train), torch.from_numpy(self.labels_train))
